const { Calendar, DateHelper, StringHelper, DomClassList } = bryntum.calendar;

let tickWidth = 50;

let eventEdit = {
    editorConfig: {
        modal: true,
        centered: true,
        anchor: null
    },
    items: {
        nameField: {
            label: 'New Label',
            placeholder: 'New Placeholder'
        },
        resourceField: {},
        exportButton: {
            type: 'button',
            icon: 'b-fa b-fa-calendar-alt',
            text: 'Ajouter à Outlook (.ics)',
            weight: 900,
            onClick() {
                const eventRecord = privates.calendar.features.eventEdit.eventRecord;

                // Add some custom ICS values (See https://tools.ietf.org/html/rfc5545 for more information)
                eventRecord.exportToICS({
                    LOCATION: eventRecord.location
                });
            }
        }
    }
};

let duplicateItem = {
    text: 'Dupliquer',
    icon: 'b-fa b-fa-clone',

    // Handler found by looking up ownership hierarchy.
    // Will find an implementation in the Calendar
    onItem: 'up.duplicateEvent'
}

let sidebarItems = {
    datePicker: {
        weekStartDay: 1
    },
    eventFilter: {},
    resourceBarFilter: {
        // Inserts just before the resourceFilter List
        weight: 190,

        // Shows a clear trigger
        clearable: true,

        placeholder: 'Ressources',
        type: 'textfield',
        keyStrokeChangeDelay: 100,

        // "up." means resolve in owner will call on the Calendar
        onChange: 'up.onResourceFilterFilterChange'
    },
    resourceFilter: {
        multiSelect: true,
        selectAllItem: true,
        toggleAllfCtrlPressed: true
    }
}

let resources = [{ id: 'r1', name: 'Google', eventColor: 'blue' }];
let events = [{ id: 1, name: 'Meeting', startDate: '2022-02-11 14:00', endDate: '2022-02-11 17:00' }];
let assignments = [{ eventId: 1, resourceId: 'r1' }];

const project = new bryntum.calendar.ProjectModel({
    resourcesData: resources, //{ id: 1, name: 'Bernard', eventColor: 'blue' }
    eventsData: events,      //{ id: 1, resourceId: 1, name: 'Pause déjeuner', startDate: '1970-01-01 12:00', endDate: '1970-01-01 14:00', recurrenceRule: 'FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR' }
    assignmentsData: assignments
});

const calendar = new Calendar({
    minHeight: 525,
    //height: window.innerHeight - $('.navbar').outerHeight() - $('.navbarsavemenu').outerHeight() - $('footer').outerHeight(),

    project: project,

    modes: {
        week: {}
    },

    mode: "week",

    sidebar: {
        items: sidebarItems
    },

    // Features named by the properties are included.
    // An object is used to configure the feature.
    features: {
        print: true,
        eventTooltip: {
            // Because we're using a context menu with an active trigger action,
            // we show the tooltip on hover (default is on click).
            showOn: 'hover',

            // Configuration options are passed on to the tooltip instance.
            // Because we are using a context menu too, keep the tooltip
            // out of the way above the event (if possible - it will try
            // other orientations if there's not enough space there).
            align: 'b-t'
        },
        eventEdit: eventEdit,
        scheduleMenu: {
            items: {
                addEvent: {}
            }
        },
        eventMenu: {
            items: {
                editEvent: {},
                deleteEvent: {},
                duplicateEvent: duplicateItem
            }
        }
    },

    // Called as the resourceFilterFilter's onChange handler
    onResourceFilterFilterChange({ value }) {
        // A filter with an id replaces any previous filter with that id.
        // Leave any other filters which may be in use in place.
        this.widgetMap.resourceFilter.store.filter({
            id: 'resourceBarFilter',
            filterBy: r => r.name.toLowerCase().startsWith(value.toLowerCase()) // a function which returns true to include the record
        });
    },

    duplicateEvent({ eventRecord }) {
        const dupe = eventRecord.copy();

        // In case it was a recurring event, the dupe will be a one-off.
        dupe.recurrence = null;
        this.eventStore.add(dupe);
    },

    // This element becomes the Calendar's encapsulating element
    appendTo: 'agenda'
});